[Freeciv-Dev] (PR#40486) S2_2: game load - buffer overflow

2008-09-14 Thread Egor Vyscrebentsov

URL: http://bugs.freeciv.org/Ticket/Display.html?id=40486 

Good daytime!

S2_2, r15205.
Loading game crashes civserver with buffer overflow.

Reason: too small buffer in player_load_vision()

Attached patch works for me, though I guess we need smth like
fc_s[n]printf().

PS. I'm having troubles with internet connection, so I may be
unreachable for a while.

-- 
Thanks, evyscr

Index: server/savegame.c
===
--- server/savegame.c	(revision 15206)
+++ server/savegame.c	(working copy)
@@ -3018,9 +3018,9 @@
   zeroline[i]= '\0';
 
   bases_halfbyte_iterate(j) {
-char buf[16]; /* enough for sprintf() below */
+char buf[32]; /* should be enough for snprintf() below */
 
-sprintf(buf, player%d.map_b%02d_%%03d, plrno, j);
+snprintf(buf, sizeof(buf), player%d.map_b%02d_%%03d, plrno, j);
 
 LOAD_MAP_DATA(ch, nat_y, ptile,
   secfile_lookup_str_default(file, zeroline, buf, nat_y),
___
Freeciv-dev mailing list
Freeciv-dev@gna.org
https://mail.gna.org/listinfo/freeciv-dev


Re: [Freeciv-Dev] (PR#40486) S2_2: game load - buffer overflow

2008-09-14 Thread Egor Vyscrebentsov

URL: http://bugs.freeciv.org/Ticket/Display.html?id=40486 

On Sun, 14 Sep 2008 03:46:25 -0700 Egor Vyscrebentsov wrote:

 S2_2, r15205.
 Loading game crashes civserver with buffer overflow.
 
 Reason: too small buffer in player_load_vision()

Looks like a copy-paste from map_load() [where this buffer
is really enough.]

 Attached patch works for me, though I guess we need smth like
 fc_s[n]printf().

And, of course, there is my_snprintf() already...

[Side note.] Game loading looks too unsafe... /me wants
to see civserver not crashing if there is no entry while
capability is present, for example

-- 
Thanks, evyscr



___
Freeciv-dev mailing list
Freeciv-dev@gna.org
https://mail.gna.org/listinfo/freeciv-dev


[Freeciv-Dev] (PR#40488) add info table

2008-09-14 Thread Tomasz Niemcewicz

URL: http://bugs.freeciv.org/Ticket/Display.html?id=40488 

info table after pressing middle mouse button, if possible it should be
added asap

info table after pressing middle mouse button, if possible it should be added asap
___
Freeciv-dev mailing list
Freeciv-dev@gna.org
https://mail.gna.org/listinfo/freeciv-dev


[Freeciv-Dev] (PR#40487) add chat buttons

2008-09-14 Thread Tomasz Niemcewicz

URL: http://bugs.freeciv.org/Ticket/Display.html?id=40487 

very important part of warclient:) I think it shouldn`t be so difficult to
add allies only and others buttons

very important part of warclient:) I think it shouldn`t be so difficult to add allies only and others buttons
___
Freeciv-dev mailing list
Freeciv-dev@gna.org
https://mail.gna.org/listinfo/freeciv-dev


[Freeciv-Dev] (PR#40453) Random assertion failures in map generation

2008-09-14 Thread Madeline Book

URL: http://bugs.freeciv.org/Ticket/Display.html?id=40453 

I'm still randomly getting the assertion failure in
latest svn in S2_1 (r15204) and S2_2 (r15205). :(

Maybe the previous patch made it a little less likely,
but it is still happening enough to be annoying (that
is, everyday during testing). Is nobody else getting
this?

It is happening for both gen 1 and 2. Gen 3 generates
the map alright, but it now seems that it places 2
or more players on single islands leaving other islands
empty (this is with startpos=0). ;(

I think that the start position allocation code needs
to be looked at more carefully. For gen1,2 it should
never abort the server unless there actually are less
land tiles on the map than there are players (even so,
aborting is a little harsh, it could just return to
pregame and say that the map generation parameters
caused the generator to fail).

For gen=3+startpos=0 it must place players one per
island, as per previous versions' behaviour and the
help texts.

(I'm not sure now that it is just the fault of the
patch in #40417; it seems that the problem is a little
deeper than just those changes I am guessing...)


This is a fairly serious bug, I would say that it is
the highest priority thing to be fixed before 2.1.7.


--
手当たり次第に知らない人を抱きしめて〜

___
Freeciv-dev mailing list
Freeciv-dev@gna.org
https://mail.gna.org/listinfo/freeciv-dev


Re: [Freeciv-Dev] (PR#40453) Random assertion failures in map generation

2008-09-14 Thread Andreas Røsdal

URL: http://bugs.freeciv.org/Ticket/Display.html?id=40453 

Hi Madeline,

I can confirm this crash, which is pretty serious.
It only occurs with gen 1 and 2, not gen 3.

The crash is fairly easy to reproduce, so then it should be
possible to find out what's wrong, right?


  - Andreas



On Sun, 14 Sep 2008, Madeline Book wrote:
 
URL: http://bugs.freeciv.org/Ticket/Display.html?id=40453 

I'm still randomly getting the assertion failure in
latest svn in S2_1 (r15204) and S2_2 (r15205). :(

Maybe the previous patch made it a little less likely,
but it is still happening enough to be annoying (that
is, everyday during testing). Is nobody else getting
this?

It is happening for both gen 1 and 2. Gen 3 generates
the map alright, but it now seems that it places 2
or more players on single islands leaving other islands
empty (this is with startpos=0). ;(

I think that the start position allocation code needs
to be looked at more carefully. For gen1,2 it should
never abort the server unless there actually are less
land tiles on the map than there are players (even so,
aborting is a little harsh, it could just return to
pregame and say that the map generation parameters
caused the generator to fail).

For gen=3+startpos=0 it must place players one per
island, as per previous versions' behaviour and the
help texts.

(I'm not sure now that it is just the fault of the
patch in #40417; it seems that the problem is a little
deeper than just those changes I am guessing...)


This is a fairly serious bug, I would say that it is
the highest priority thing to be fixed before 2.1.7.


--
ÿÿ

___
Freeciv-dev mailing list
Freeciv-dev@gna.org
https://mail.gna.org/listinfo/freeciv-dev

___
Freeciv-dev mailing list
Freeciv-dev@gna.org
https://mail.gna.org/listinfo/freeciv-dev


[Freeciv-Dev] (PR#40488) add info table

2008-09-14 Thread Madeline Book

URL: http://bugs.freeciv.org/Ticket/Display.html?id=40488 

 [EMAIL PROTECTED] - Sun Sep 14 18:21:36 2008]:
 
 info table after pressing middle mouse button, if possible it
 should be added asap

What exactly do you want to have in the info popup? Refresh
my memory on the extra stuff that warclient has that is not
in 2.1.6. (Please be specific in your feature requests.) :|


--
この計画は完璧だ。

___
Freeciv-dev mailing list
Freeciv-dev@gna.org
https://mail.gna.org/listinfo/freeciv-dev